#!/bin/sh

[ -z "$ROOT" ] && ROOT=/www
CONFIG=$ROOT/config
SCRIPT=$ROOT/script

source $CONFIG/ap.conf
source $CONFIG/ng.conf

echo > /etc/config/network

uci set network.loopback=interface
uci set network.loopback.ifname='lo'
uci set network.loopback.proto='static'
uci set network.loopback.ipaddr='127.0.0.1'
uci set network.loopback.netmask='255.0.0.0'

# NETWORK - SWITCH
if [ "$HAS_SWITCH" == true ] ; then
  uciKey=network.switch
  uci set $uciKey=switch
  uci set $uciKey.name=switch0
  uci set $uciKey.reset=1
  uci set $uciKey.enable_vlan=1

  uciKey=network.svwan
  uci set $uciKey=switch_vlan
  uci set $uciKey.device=switch0
  uci set $uciKey.ports="${CPU_SWITCH_PORT:-0}t ${WAN_SWITCH_PORT}"
  wanEthVlan=`echo $WAN_ETH | cut -d "." -f 2`
  uci set $uciKey.vlan=$wanEthVlan

  uciKey=network.svlan
  uci set $uciKey=switch_vlan
  uci set $uciKey.device=switch0
  uci set $uciKey.ports="${CPU_SWITCH_PORT:-0}t ${LAN_SWITCH_PORT}"
  lanEthVlan=`echo $LAN_ETH | cut -d "." -f 2`
  uci set $uciKey.vlan=$lanEthVlan
fi

# NETWORK - VLAN


# NETWORK - WAN
uciKey=network.wan
uci -q del $uciKey
if [ ! -z "$WAN_ETH" ] ; then
  uci set $uciKey=interface
  uci set $uciKey.type=bridge
  uci set $uciKey.proto=dhcp
  uci set $uciKey.defaultroute=1

  if [ "$WAN_PROTO" == static ] ; then
    uci set $uciKey.proto=static
    uci set $uciKey.ipaddr="$WAN_IP"
    uci set $uciKey.netmask="$WAN_NETMASK"
    uci set $uciKey.gateway="$WAN_GATEWAY"
  elif [ "$WAN_PROTO" == pppoe ] ; then
    uci set $uciKey.proto=pppoe
    uci set $uciKey.username="$WAN_PPP_USERNAME"
    uci set $uciKey.password="$WAN_PPP_PASSWORD"
  fi
  uci add_list $uciKey.ifname="$WAN_ETH"

  [ -z "$WAN_VLAN" ] || uci set $uciKey.defaultroute=0
fi

# NETWORK - LAN 0
uciKey=network.lan
uci -q del $uciKey
if [ "$LAN2_BRIDGE" == 1 ] && [ ! -z "$LAN_ETH" ] ; then
  if [ ! -z "$LAN2_VLAN" ] ; then
    sh $SCRIPT/setup/setup-vlan $LAN2_VLAN
    uci add_list network.vlan$LAN2_VLAN.ifname="$LAN_ETH"
  else
    uci add_list network.wan.ifname="$LAN_ETH"
  fi
else
  uci set $uciKey=interface
  uci set $uciKey.ifname="$LAN_ETH"
  uci set $uciKey.proto=static
  if [ -n "$LAN2_IP" ] ; then
    uci set $uciKey.ipaddr="$LAN2_IP"
    uci set $uciKey.netmask="$LAN2_NETMASK"
  else
    uci set $uciKey.ipaddr="192.168.102.1"
    uci set $uciKey.netmask="255.255.255.0"
  fi
fi

# NETWORK - DEBUG
uciKey=network.debug
uci -q del $uciKey
uci set $uciKey=interface
uci set $uciKey.type=bridge
uci set $uciKey.ifname=debug0
uci set $uciKey.proto=static
uci set $uciKey.ipaddr=10.69.69.1
uci set $uciKey.netmask=255.255.255.0


# NETWORK - STATIC ROUTES
echo "$STATIC_ROUTES" | tr ";" "\n" | awk -F':' '{
  if ($1 == "") return;
  key = "network.route"NR;
  system("uci set "key"=route");
  system("uci set "key".target="$1);
  system("uci set "key".netmask="$2);
  system("uci set "key".gateway="$3);
  system("uci set "key".interface="$4);
}'

ssids=`seq 1 "$NO_SSID"`
for ssid in $ssids; do
  sh $SCRIPT/setup/setup-network-ssid.sh $ssid

  eval vlan="\$SSID${ssid}_VLAN"
  [ ! -z "$vlan" -a ! -z "$WAN_ETH" ] && sh $SCRIPT/setup/setup-vlan.sh $vlan
done