#!/bin/sh

[ -z "$ROOT" ] && ROOT=/www
CONFIG=$ROOT/config
SCRIPT=$ROOT/script

source $CONFIG/ap.conf
source $CONFIG/ng.conf

source $SCRIPT/utils/network.sh

setupVlan() {
  local vlan="$1"
  local key="network.vlan${vlan}"
  if [ -z "`uci get $key 2>/dev/null`" ] ; then
    uci set $key=interface
    uci set $key.type=bridge
    uci set $key.proto=dhcp
    uci set $key.defaultroute=0

    eval local proto="\$VLAN${vlan}_PROTO"
    eval local vlanIp="\$VLAN${vlan}_IP"
    eval local vlanGateway="\$VLAN${vlan}_GATEWAY"
    if [ "$proto" == static ] ; then
      uci set $key.proto=static
      eval uci set $key.netmask="\$VLAN${vlan}_NETMASK"
      uci set $key.ipaddr="$vlanIp"
      uci set $key.gateway="$vlanGateway"
    fi

    if [ "$WAN_VLAN" == "$vlan" ] ; then
      uci set $key.defaultroute=1
    fi

    local inf="`getVlanInf $vlan`"
    uci add_list "$key.ifname=$inf"

    local uciKey="dhcp.vlan${vlan}"
    uci -q del $uciKey
    eval local dhcp="\$VLAN${vlan}_DHCP"
    if [ "$proto" == static -a "$dhcp" == 1 ] ; then
      uci set $uciKey=dhcp
      uci set $uciKey.instance=main
      uci set $uciKey.interface="vlan$vlan"
      uci set $uciKey.force=1

      eval local dhcpStart="\$VLAN${vlan}_DHCP_START"
      eval local dhcpLimit="\$VLAN${vlan}_DHCP_LIMIT"
      eval local dhcpLeaseTime="\$VLAN${vlan}_DHCP_LEASETIME"
      eval local dhcpLeaseTimeUnit="\$VLAN${vlan}_DHCP_LEASETIME_UNIT"

      [ -n "$dhcpStart" ] && uci set $uciKey.start="$dhcpStart" || uci set $uciKey.start=50
      [ -n "$dhcpLimit" ] && uci set $uciKey.limit="$dhcpLimit" || uci set $uciKey.limit=100
      [ -n "$dhcpLeaseTime" -a -n "$dhcpLeaseTimeUnit" ] && uci set $uciKey.leasetime="${dhcpLeaseTime}${dhcpLeaseTimeUnit}"

      eval local dhcpDns1="\$VLAN${vlan}_DHCP_DNS1"
      eval local dhcpDns2="\$VLAN${vlan}_DHCP_DNS2"
      eval local dhcpGateway="\$VLAN${vlan}_DHCP_GATEWAY"
      local dnsIps=""
      [ -z "$dhcpDns1" ] || dnsIps="${dnsIps},$dhcpDns1"
      [ -z "$dhcpDns2" ] || dnsIps="${dnsIps},$dhcpDns2"
      [ -z "$dnsIps" -a ! -z "$vlanIp" ] && dnsIps=",${vlanIp}"
      [ -z "$dhcpGateway" ] && dhcpGateway="$vlanGateway"

      [ -z "$dhcpGateway" ] || uci add_list $uciKey.dhcp_option="3,${dhcpGateway}"
      [ -z "$dnsIps" ] || uci add_list $uciKey.dhcp_option="6${dnsIps}"
    fi
  fi

  local uciKey="network.sv${vlan}"
  uci -q del $uciKey
  if [ "$HAS_SWITCH" == true ] ; then
    uci set $uciKey=switch_vlan
    uci set $uciKey.device=switch0
    uci set $uciKey.ports="${CPU_SWITCH_PORT:-0}t ${WAN_SWITCH_PORT}t"
    uci set $uciKey.vlan=$vlan
  fi
}

setupVlan $1